OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "Favorites" : "Preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "\"remote account\"" : "\"account remoto\"",
    "You created {file}" : "Hai creato {file}",
    "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creato un file cifrato in {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "You changed an encrypted file in {file}" : "Hai cambiato un file cifrato in {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha cambiato un file cifrato in {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "You deleted an encrypted file in {file}" : "Hai eliminato un file cifrato in {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha eliminato un file cifrato in {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user} ha ripristinato {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Hai rinominato {oldfile} (nascosto) in {newfile} (nascosto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Hai rinominato {oldfile} (nascosto) in {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Hai rinominato {oldfile} in {newfile} (nascosto)",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ha rinominato {oldfile} (nascosto) in {newfile} (nascosto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ha rinominato {oldfile} (nascosto) in {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ha rinominato {oldfile} in {newfile} (nascosto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "Files" : "File",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un file preferito o una cartella è stato <strong>modificato</strong>",
    "Failed to authorize" : "Impossibile dare l'autorizzazione",
    "Invalid folder path" : "Percorso della cartella non valido",
    "Folder not found" : "Cartella non trovata",
    "The file cannot be found" : "Il file non può essere trovato",
    "The destination path does not exist: %1$s" : "Il percorso di destinazione non esiste: %1$s",
    "You do not have permission to create a file at the specified location" : "Non hai l'autorizzazione per creare un file nella posizione specificata",
    "The file could not be converted." : "Il file non può essere convertito.",
    "Could not get relative path to converted file" : "Impossibile ottenere il percorso relativo al file convertito",
    "Favorite files" : "File preferiti",
    "No favorites" : "Nessun preferito",
    "More favorites" : "Altri preferiti",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "Accept" : "Accetta",
    "Reject" : "Rifiuta",
    "Incoming ownership transfer from {user}" : "Trasferimento di proprietà in ingresso da {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vuoi accettare {path}?\n\nNota: il processo di trasferimento dopo l'accettazione potrebbe richiedere fino a un'ora.",
    "Ownership transfer denied" : "Trasferimento di proprietà negato",
    "Your ownership transfer of {path} was denied by {user}." : "Il tuo trasferimento di proprietà di {path} è stato negato da {user}.",
    "Ownership transfer failed" : "Trasferimento di proprietà non riuscito",
    "Your ownership transfer of {path} to {user} failed." : "Il tuo trasferimento di proprietà di {path} a {user} non è riuscito.",
    "The ownership transfer of {path} from {user} failed." : "Il trasferimento di proprietà di {path} da {user} non è riuscito.",
    "Ownership transfer done" : "Trasferimento di proprietà completato",
    "Your ownership transfer of {path} to {user} has completed." : "Il tuo trasferimento di proprietà di {path} a {user} è completato.",
    "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
    "in %s" : "in %s",
    "Transferred from %1$s on %2$s" : "Trasferito da %1$s su %2$s",
    "Files compatibility" : "Compatibilità di File",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Consenti di limitare i nomi di file per assicurarsi che i file vengano sincronizzati con tutti i client. In modo predefinito, tutti i nomi di file validi su POSIX (es. Linux o macOS) sono consentiti.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "È anche possibile migrare i file automaticamente dopo aver abilitato questa impostazione; fare riferimento alla documentazione relativa al comando occ.",
    "Enforce Windows compatibility" : "Imponi la compatibilità con Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ciò bloccherà i nomi di file non validi sui sistemi Windows, come l'uso di nomi riservati o caratteri speciali. Tuttavia non verrà imposta la compatibilità con le maiuscole/minuscole.",
    "File Management" : "Gestione dei file",
    "Home" : "Home",
    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
    "Reload current directory" : "Ricarica la cartella corrente",
    "Go to the \"{dir}\" directory" : "Vai alla cartella \"{dir}\"",
    "Current directory path" : "Percorso della cartella corrente",
    "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
    "You do not have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
    "Drag and drop files here to upload" : "Trascina i file qui per caricarli",
    "Favorite" : "Preferito",
    "Back" : "Indietro",
    "Toggle selection for file \"{displayName}\"" : "Attiva/disattiva la selezione per il file \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Attiva/disattiva la selezione per la cartella \"{displayName}\"",
    "File is loading" : "Il file è in caricamento",
    "Folder is loading" : "La cartella è in caricamento",
    "Filename" : "Nome file",
    "Folder name" : "Nome della cartella",
    "This node is unavailable" : "Questa nodo non è disponibile",
    "Another entry with the same name already exists." : "Esiste già un'altra voce con lo stesso nome.",
    "Invalid filename." : "Nome di file non valido.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Rinominato \"{oldName}\" in \"{newName}\"",
    "Rename file" : "Rinomina file",
    "Folder" : "Cartella",
    "Pending" : "In corso",
    "Unknown date" : "Data sconosciuta",
    "Clear filter" : "Pulisci il filtro",
    "Modified" : "Modificato",
    "Type" : "Tipo",
    "Active filters" : "Filtri attivi",
    "Remove filter" : "Rimuovi filtro",
    "Total rows summary" : "Riepilogo totale delle righe",
    "Toggle selection for all files and folders" : "Attiva/disattiva la selezione per tutti i file e le cartelle",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" non riuscito su alcuni elementi",
    "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
    "Actions" : "Azioni",
    "(selected)" : "(selezionato)",
    "List of files and folders." : "Lista di file e cartelle.",
    "You have used your space quota and cannot upload files anymore." : "Hai esaurito la tua quota di spazio e non puoi più caricare file.",
    "Column headers with buttons are sortable." : "Le intestazioni di colonna con pulsanti sono ordinabili.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Questa lista non è stata mostrata completamente per ragioni di prestazioni. I file verranno mostrati durante la navigazione della lista.",
    "File not found" : "File non trovato",
    "{count} selected" : "{count} selezionati",
    "{usedQuotaByte} used" : "{usedQuotaByte} usato",
    "{used} of {quota} used" : "{used} di {quota} utilizzati",
    "{relative}% used" : "{relative}% usato",
    "Could not refresh storage stats" : "Impossibile aggiornare le statistiche di archiviazione",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage information" : "Informazioni di archiviazione",
    "Storage quota" : "Limite di archiviazione",
    "New folder" : "Nuova cartella",
    "Create new folder" : "Crea una nuova cartella",
    "This name is already in use." : "Questo nome è già utilizzato.",
    "Create" : "Crea",
    "Fill template fields" : "Compila i campi del modello",
    "Submitting fields …" : "Invio dei campi …",
    "Submit" : "Invia",
    "Choose a file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Transfer" : "Trasferisci",
    "Transfer {path} to {userid}" : "Trasferisci {path} a {userid}",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Unknown error" : "Errore sconosciuto",
    "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
    "Cannot transfer ownership of a file or folder you do not own" : "Impossibile trasferire la proprietà di un file o di una cartella di cui non sei proprietario",
    "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
    "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Change" : "Modifica",
    "New owner" : "Nuovo proprietario",
    "Keep {old}" : "Mantieni {old}",
    "Keep without extension" : "Mantenere senza estensione",
    "Use {new}" : "Usa {new}",
    "Remove extension" : "Rimuovi estensione",
    "Change file extension" : "Cambia estensione file",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Modificando l'estensione del file da \"{old}\" a\"{new}\" potrebbe rendere il file illeggibile.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Rimuovendo dell'estensione del file \"{old}\" potrebbe rendere il file illeggibile.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Aggiungere l'estensione del file \"{new}\" potrebbe rendere il file illeggibile.",
    "Do not show this dialog again." : "Non visualizzare più questa finestra di dialogo.",
    "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
    "Choose {file}" : "Scegli {file}",
    "Share" : "Condividi",
    "Shared by link" : "Condivisi tramite collegamento",
    "Shared" : "Condiviso",
    "Switch to list view" : "Passa alla vista elenco",
    "Switch to grid view" : "Passa alla vista griglia",
    "The file could not be found" : "Il file non è stato trovato",
    "Upload was cancelled by user" : "Caricamento annullato dall'utente",
    "Not enough free space" : "Spazio libero insufficiente",
    "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
    "Error during upload: {message}" : "Errore durante il caricamento: {message}",
    "Error during upload, status code {status}" : "Errore durante il caricamento, codice di stato {status}",
    "Unknown error during upload" : "Errore sconosciuto durante il caricamento",
    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
    "Loading current folder" : "Sto caricando la cartella corrente",
    "Retry" : "Riprova",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
    "Go back" : "Indietro",
    "Filter file names …" : "Filtra i nomi dei file …",
    "Views" : "Viste",
    "Files settings" : "Impostazioni File",
    "Your files" : "I tuoi files",
    "Open in files" : "Apri in file",
    "File cannot be accessed" : "Il file non possono essere acceduti",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Impossibile trovare il file oppure non disponi dei permessi per visualizzarlo. Chiedi al mittente di condividerlo.",
    "Clipboard is not available" : "Appunti non disponibili",
    "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
    "Sort favorites first" : "Ordina prima i preferiti",
    "Sort folders before files" : "Ordina cartelle prima dei files",
    "Show hidden files" : "Mostra i file nascosti",
    "Crop image previews" : "Ritaglia le anteprime delle immagini",
    "Enable the grid view" : "Attiva visuale a griglia",
    "Enable folder tree" : "Abilita l'albero delle cartelle",
    "Additional settings" : "Impostazioni aggiuntive",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL WebDAV",
    "Copy to clipboard" : "Copia negli appunti",
    "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se hai abilitato il 2FA, devi creare ed usare una nuova password per l'applicazione facendo clic qui.",
    "Warnings" : "Avvertenze",
    "Prevent warning dialogs from open or reenable them." : "Impedire l'apertura delle finestre di dialogo di avviso o riattivarle.",
    "Show a warning dialog when changing a file extension." : "Mostra una finestra di dialogo di avviso quando si modifica l'estensione di un file.",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Speed up your Files experience with these quick shortcuts." : "Velocizza la tua esperienza con i File con queste rapide scorciatoie.",
    "Open the actions menu for a file" : "Aprire il menu delle azioni per un file",
    "Rename a file" : "Rinominare un file",
    "Delete a file" : "Eliminare un file",
    "Favorite or remove a file from favorites" : "Aggiungere ai Preferiti o rimuovere un file dai preferiti",
    "Manage tags for a file" : "Gestire i tag per un file",
    "Selection" : "Selezione",
    "Select all files" : "Seleziona tutti i file",
    "Deselect all files" : "Deseleziona tutti i file",
    "Select or deselect a file" : "Seleziona o deseleziona un file",
    "Select a range of files" : "Seleziona un intervallo di file",
    "Navigation" : "Navigazione",
    "Navigate to the parent folder" : "Passare alla cartella padre",
    "Navigate to the file above" : "Vai al file sopra",
    "Navigate to the file below" : "Vai al file qui sotto",
    "Navigate to the file on the left (in grid mode)" : "Navigare nel file a sinistra (in modalità griglia)",
    "Navigate to the file on the right (in grid mode)" : "Navigare nel file a destra (in modalità griglia)",
    "View" : "Visualizza",
    "Toggle the grid view" : "Attiva la vista a griglia",
    "Open the sidebar for a file" : "Aprire la barra laterale per un file",
    "Show those shortcuts" : "Mostra quelle scorciatoie",
    "You" : "Tu",
    "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
    "Owner" : "Proprietario",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Tags" : "Etichette",
    "Blank" : "Vuoto",
    "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
    "Pick a template for {name}" : "Scegli un modello per {name}",
    "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
    "Creating file" : "Creazione del file",
    "Save as {displayName}" : "Savlva come {displayName}",
    "Save as …" : "Salva come …",
    "Converting files …" : "Conversione dei file …",
    "Failed to convert files: {message}" : "Impossibile convertire i file: {message}",
    "All files failed to be converted" : "Non è stato possibile convertire tutti i file",
    "One file could not be converted: {message}" : "Un file non può essere convertito: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Un file non è stato convertito","%nfile non possono essere convertiti","%n file non possono essere convertiti"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Un file convertito correttamente","%nfile convertiti con successo","%n file convertiti con successo"],
    "Files successfully converted" : "File convertiti con successo",
    "Failed to convert files" : "Impossibile convertire i file",
    "Converting file …" : "Conversione del file …",
    "File successfully converted" : "File convertito con successo",
    "Failed to convert file: {message}" : "Impossibile convertire il file: {message}",
    "Failed to convert file" : "Impossibile convertire il file",
    "Deletion cancelled" : "Eliminazione annullata",
    "Leave this share" : "Abbandona questa condivisione",
    "Leave these shares" : "Abbandona queste condivisioni",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Disconnect storages" : "Disconnetti il supporto di archiviazione",
    "Delete permanently" : "Elimina permanentemente",
    "Delete and unshare" : "Elimina e annulla la condivisione",
    "Delete file" : "Elimina file",
    "Delete files" : "Elimina i file",
    "Delete folder" : "Elimina cartella",
    "Delete folders" : "Elimina la cartella",
    "Delete" : "Elimina",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Stai per eliminare permanentemente {count} elemento","Stai per eliminare permanentemente {count} elementi","Stai per eliminare permanentemente {count} elementi"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Stai per eliminare {count} elemento","Stai per eliminare {count} elementi","Stai per eliminare {count} elementi"],
    "Confirm deletion" : "Conferma l'eliminazione",
    "Cancel" : "Annulla",
    "Moving \"{source}\" to \"{destination}\" …" : "Sposta \"{source}\" in \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copia \"{source}\" in \"{destination}\" …",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
    "(copy)" : "(copia)",
    "(copy %n)" : "(copia %n)",
    "Move cancelled" : "Spostamento cancellato",
    "A file or folder with that name already exists in this folder" : "Esiste già un file o una cartella con quel nome in questa cartella",
    "The files are locked" : "I files sono bloccati",
    "The file does not exist anymore" : "Il file non esiste più",
    "Choose destination" : "Scegli la destinazione",
    "Copy to {target}" : "Copia in {target}",
    "Copy" : "Copia",
    "Move to {target}" : "Sposta in {target}",
    "Move" : "Sposta",
    "Move or copy operation failed" : "Operazione di spostamento o copia fallita",
    "Move or copy" : "Sposta o copia",
    "Cancelled move or copy of \"{filename}\"." : "Spostamento o copia di \"{filename}\" annullato.",
    "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
    "Open folder {displayName}" : "Apri la cartella {displayName}",
    "Open in Files" : "Apri in File",
    "Open file locally" : "Apri file localmente",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Il file dovrebbe ora aprirsi sul tuo dispositivo. In caso contrario, controlla di aver installato l'app desktop.",
    "Retry and close" : "Riprova e chiudi",
    "Open online" : "Apri online",
    "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
    "Open locally" : "Aprire localmente",
    "Rename" : "Rinomina",
    "Open details" : "Apri i dettagli",
    "View in folder" : "Visualizza nella cartella",
    "Today" : "Ogg",
    "Last 7 days" : "Ultimi 7 giorni",
    "Last 30 days" : "Ultimi 30 giorni",
    "This year ({year})" : "Quest'anno ({year})",
    "Last year ({year})" : "L'anno scorso ({year})",
    "Documents" : "Documenti",
    "Spreadsheets" : "Fogli elettronici",
    "Presentations" : "Presentazioni",
    "PDFs" : "PDF",
    "Folders" : "Cartelle",
    "Audio" : "Audio",
    "Photos and images" : "Foto e immagini",
    "Videos" : "Video",
    "New folder creation cancelled" : "Creazione nuova cartella annullata",
    "Created new folder \"{name}\"" : "Crea una nuova cartella \"{name}\"",
    "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
    "Create templates folder" : "Crea cartella dei modelli",
    "Templates" : "Modelli",
    "New template folder" : "Nuova cartella dei modelli",
    "In folder" : "Nella cartella",
    "Search in folder: {folder}" : "Cerca nella cartella: {folder}",
    "One of the dropped files could not be processed" : "Impossibile elaborare uno dei file eliminati",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Il tuo browser non supporta l'API del file system. Le directory non verranno caricate",
    "No files to upload" : "Nessun file da caricare",
    "Unable to create the directory {directory}" : "Impossibile creare la directory {directory}",
    "Some files could not be uploaded" : "Alcuni file non possono essere caricati",
    "Files uploaded successfully" : "Files caricati correttamente",
    "No files to process" : "Nessun file da elaborare",
    "Some files could not be copied" : "Alcuni file non possono essere copiati",
    "Some files could not be moved" : "Alcuni file non possono essere spostati",
    "Files copied successfully" : "File copiati correttamente",
    "Files moved successfully" : "File spostati correttamente",
    "Conflicts resolution skipped" : "Risoluzione dei conflitti saltata",
    "Upload cancelled" : "Caricamento annullato",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Unexpected error: {error}" : "Errore imprevisto: {error}",
    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
    "_%n hidden_::_%n hidden_" : ["%n nascosto","%n nascosti","%n nascosti"],
    "Filename must not be empty." : "Il nome del file non può essere vuoto.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" non è consentito in un nome di file.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" è un nome riservato e non consentito per i nomi di file.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" non è un tipo di file consentito.",
    "Filenames must not end with \"{extension}\"." : "I nomi di file non possono terminare con \"{extension}\".",
    "List of favorite files and folders." : "Elenco dei file e delle cartelle preferiti.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "All files" : "Tutti i file",
    "List of your files and folders." : "Lista dei tuoi file e cartelle.",
    "All folders" : "Tutte le cartelle",
    "Personal files" : "File personali",
    "List of your files and folders that are not shared." : "Elenco dei file e delle cartelle che non sono condivisi.",
    "No personal files found" : "Nessun file personale trovato",
    "Files that are not shared will show up here." : "I file che non vengono condivisi verranno visualizzati qui.",
    "Recent" : "Recenti",
    "List of recently modified files and folders." : "Lista di file e cartelle modificati di recente.",
    "No recently modified files" : "Nessun file modificato di recente",
    "Files and folders you recently modified will show up here." : "I file e le cartelle che hai modificato di recente saranno mostrati qui.",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "File could not be found" : "Il file non può essere trovato",
    "Download" : "Scarica",
    "Show list view" : "Mostra la vista elenco",
    "Show grid view" : "Mostra la visualizzazione griglia",
    "Close" : "Chiudi",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
    "Upload cancelled." : "Caricamento annullato.",
    "Processing files …" : "Elaborazione file in corso…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
    "File could not be uploaded" : "Il file non può essere caricato",
    "Uploading …" : "Caricamento in corso...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Caricamento … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
    "Choose target folder" : "Scegli la cartella di destinazione",
    "Set reminder" : "Imposta promemoria",
    "Edit locally" : "Modifica localmente",
    "Open" : "Apri",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Details" : "Dettagli",
    "Please select tag(s) to add to the selection" : "Seleziona un'etichetta(e) da aggiungere alla selezione",
    "Apply tag(s) to selection" : "Applica etichetta(e) alla selezione",
    "Select directory \"{dirName}\"" : "Seleziona cartella \"{dirName}\"",
    "Select file \"{fileName}\"" : "Seleziona file \"{fileName}\"",
    "Unable to determine date" : "Impossibile determinare la data",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "copy" : "copia",
    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Could not fetch file details \"{file}\"" : "Impossibile recuperare i dettagli del file \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti","inclusi %n nascosti"],
    "You do not have permission to upload or create files here" : "Non disponi dei permessi per caricare o creare file qui",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "New file/folder menu" : "Nuovo menu file/cartella",
    "Select file range" : "Seleziona intervallo di file",
    "{used}%" : "{used}%",
    "{used} used" : "{used} utilizzati",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La cartella di gruppo \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'archiviazione esterna \"{mountPoint}\" è piena, i file non possono più essere caricati o sincronizzati!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più caricati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Copy direct link (only works for people who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
    "Upload file" : "Carica file",
    "Not favorited" : "Non preferito",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "You don't have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
    "Storage informations" : "Informazioni di archiviazione",
    "Choose file" : "Scegli file",
    "Go to the previous folder" : "Vai alla cartella precedente",
    "Open the files app settings" : "Apri le impostazioni dell'applicazione File",
    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
    "Edit file locally" : "Modifica il file localmente",
    "Edit online" : "Modifica online",
    "Create new templates folder" : "Crea una nuova cartella dei modelli",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartelle","{folderCount} cartelle"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} file","{fileCount} file"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file e {folderCount} cartella","1 file e {folderCount} cartelle","1 file e {folderCount} cartelle"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file e 1 cartella","{fileCount} file e 1 cartella","{fileCount} file e 1 cartella"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} file e {folderCount} cartelle",
    "List of favorites files and folders." : "Lista di file e cartelle preferiti.",
    "Personal Files" : "File personali",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "Favored" : "Preferito",
    "Favor" : "Preferiti",
    "Not favored" : "Non preferito",
    "Submitting fields…" : "Invio dei campi…",
    "Filter filenames…" : "Filtra nomi di file…",
    "{count} files could not be converted" : "{count} file non possono essere convertiti",
    "{count} files successfully converted" : "{count} file convertiti con successo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
